@@ -18,7 +18,8 @@ def performance(data: str, model: str, report=True,
     The metrics are calculated across all the files within a data folder.
 
     :param data: name of the data set
-    :param model: path to the TOML file that contains the model information
+    :param model: path to the configuration file (.toml file) that contains
+        the metadata of the model
     :param report: whether to create a performance report or not (default:
         True)
     :param title: title of the configuration (default: "Config Performance
