@@ -48,16 +48,15 @@ def cdc(
     variables.
 
     :param data: name of the data set
-    :param model: path to the TOML file that contains the model information
+    :param model: path to the configuration file (.toml file) that contains
+        the metadata of the model
     :param distance_weights: array of weights to multiply the distance
-                             in each coordinate with. If set to None,
-                             reasonable default values are calculated
-                             depending on the value range for quantitative
-                             and the number of features for categorical
-                             features.
+        in each coordinate with. If set to None, reasonable default values are
+        calculated depending on the value range for quantitative and the
+        number of features for categorical features.
     :param iteration_step: number of iterations in the attack
-    :param target_category: the target category this algorithm tries to
-                            get the points classified as
+    :param target_category: the target category this algorithm tries to get
+        the points classified as
     :param mask: list of binary values that decide whether a variable can be
         perturbed by the attack, the list length must be the number of
         variables
