@@ -47,21 +47,20 @@ def evolution_mixed(
     variables.
 
     :param data: name of the data set
-    :param model: path to the TOML file that contains the model information
+    :param model: path to the configuration file (.toml file) that contains
+        the metadata of the model
     :param distance_weights: array of weights to multiply the distance
-                             in each coordinate with. If set to None,
-                             reasonable default values are calculated
-                             depending on the value range for quantitative
-                             and the number of categories for categorical
-                             features.
+        in each coordinate with. If set to None, reasonable default values are
+        calculated depending on the value range for quantitative and the
+        number of categories for categorical features.
     :param evolutionary_steps: the number of generations the population goes
-                               through
+        through
     :param population_nr: the total size of the population the evolutionary
-                          strategy uses
+        strategy uses
     :param selection_nr: the number of members of the population to be
-                         selected from each generation
-    :param target_category: the target category this algorithm tries to
-                            get the points classified as
+        selected from each generation
+    :param target_category: the target category this algorithm tries to get
+        the points classified as
     :param mask: list of binary values that decide whether a variable can be
         perturbed by the attack, the list length must be the number of
         variables
