@@ -33,7 +33,8 @@ def increase(data: str,
     - scikit-learn classification feedforward models
 
     :param data: name of the data set
-    :param model: path to the TOML file that contains the model information
+    :param model: path to the configuration file (.toml file) that contains
+        the metadata of the model
     :param variable_name: name of the variable to corrupt
     :param step_length: number of data points with a constant value before
         the next increase/decrease
