@@ -218,7 +218,7 @@ def fgsm_distribution_factory(epsilon: List[float],
     :param step_length: number of time steps with constant value before next
     increase or decrease
     :param target_output: the index of the output neuron the algorithm tries
-                          to modify (only relevant for multiregression models)
+        to modify (only relevant for multiregression models)
     """
     distribution = FGSMDistribution(
         epsilon=epsilon,
@@ -274,6 +274,8 @@ def correlation_distribution_factory(epsilon: List[float],
         variables
     :param step_length: number of time steps with constant value before next
         increase or decrease
+    :param target_output: the index of the output neuron the algorithm tries
+        to modify (only relevant for multiregression models)
     """
     distribution = CorrelationDistribution(
         epsilon=epsilon,
@@ -330,8 +332,7 @@ def peak_distribution_factory(epsilon: List[float],
     :param step_length: number of time steps with constant value before next
     increase or decrease
     :param target_output: the index of the output neuron the algorithm tries
-                          to maximize the error of (only relevant for
-                          multiregression models)
+        to maximize the error of (only relevant for multiregression models)
     """
     distribution = PeakDistribution(
         epsilon=epsilon,
@@ -398,7 +399,7 @@ def blackbox_distribution_factory(epsilon: List[float],
     :param step_length: number of time steps with constant value before next
     increase or decrease
     :param target_output: the index of the output neuron the algorithm tries
-                          to modify (only relevant for multiregression models)
+        to modify (only relevant for multiregression models)
     """
     distribution = BlackboxDistribution(
         epsilon=epsilon,
@@ -455,7 +456,8 @@ def kri(data: str, model: str,
     parameters.
 
     :param data: name of the data set
-    :param model: path to the TOML file that contains the model information
+    :param model: path to the configuration file (.toml file) that contains
+        the metadata of the model
     :param p_x: list of the probabilities of occurrence of a data file in the
         deployment context, the length of the list must be equal to the number
         of data files in the provided data set and the probabilities must sum
