@@ -1,5 +1,10 @@
 """The only requirement for using aidkit is having a license. Once you have
 purchased your license, we will provide you with the credentials (subdomain
 and token) needed for the authentication process.
+
+The simple three next steps are:
+    1. :ref:`upload-data`
+    2. :ref:`upload-model`
+    3. :ref:`execute-analyses`
 """
 from aidkitcli.data_access.authentication import authorize
