@@ -33,7 +33,8 @@ def aggregated_constant(data: str,
     - scikit-learn classification feedforward models
 
     :param data: name of the data set
-    :param model: path to the TOML file that contains the model information
+    :param model: path to the configuration file (.toml file) that contains
+        the metadata of the model
     :param variable_name: name of the variable to corrupt
     :param start_constant: first value the chosen variable is set to
     :param end_constant: maximal corruption value that should not be surpassed
