@@ -30,7 +30,8 @@ def aggregated_relative_constant(data: str,
     the ML models supported are Keras regression recurrent models.
 
     :param data: name of the data set
-    :param model: path to the TOML file that contains the model information
+    :param model: path to the configuration file (.toml file) that contains
+        the metadata of the model
     :param variable_name: name of the variable to corrupt
     :param start_relative_constant: starting value of the perturbation
     :param end_relative_constant: maximal value of the corruption that should
