@@ -292,13 +292,13 @@ def fgsm_distribution_factory(epsilon: List[float],
     :param perturbation_length: number of data points perturbed
     :param iteration_step: number of iterations in the attack
     :param ascend: whether the output value should increase (True) or decrease
-    (False). Only needed if the attack is applied to a regression model
+        (False). Only needed if the attack is applied to a regression model
     :param mask: list of binary values that decide whether a variable can be
-    perturbed by the attack, the list length must be the number of variables
+        perturbed by the attack, the list length must be the number of variables
     :param step_length: number of time steps with constant value before next
-    increase or decrease
+        increase or decrease
     :param target_output: the index of the output neuron the algorithm tries
-                          to modify (only relevant for multiregression models)
+        to modify (only relevant for multiregression models)
     """
     distribution = FGSMDistribution(
         epsilon=epsilon,
@@ -408,8 +408,7 @@ def peak_distribution_factory(epsilon: List[float],
     :param step_length: number of time steps with constant value before next
     increase or decrease
     :param target_output: the index of the output neuron the algorithm tries
-                          to maximize the error of (only relevant for
-                          multiregression models)
+        to maximize the error of (only relevant for multiregression models)
     """
     distribution = PeakDistribution(
         epsilon=epsilon,
@@ -475,7 +474,7 @@ def blackbox_distribution_factory(epsilon: List[float],
     :param step_length: number of time steps with constant value before next
     increase or decrease
     :param target_output: the index of the output neuron the algorithm tries
-                          to modify (only relevant for multiregression models)
+        to modify (only relevant for multiregression models)
     """
     distribution = BlackboxDistribution(
         epsilon=epsilon,
@@ -530,7 +529,8 @@ def kri(data: str, model: str,
     parameters.
 
     :param data: name of the data set
-    :param model: path to the TOML file that contains the model information
+    :param model: path to the configuration file (.toml file) that contains
+        the metadata of the model
     :param p_x: list of the probabilities of occurrence of a data file in the
         deployment context, the length of the list must be equal to the number of
         data files in the provided data set and the probabilities must sum up to 1
