@@ -29,7 +29,8 @@ def relative_constant(data: str,
     - scikit-learn classification feedforward models
 
     :param data: name of the data set
-    :param model: path to the TOML file that contains the model information
+    :param model: path to the configuration file (.toml file) that contains
+        the metadata of the model
     :param variable_name: name of the variable to corrupt
     :param relative_constant: constant value added to the original data
     :param start_index: data points before this index will not be perturbed
