@@ -35,7 +35,7 @@ class StoredModel:
     Data class to store all the information about a model needed to execute an
     analysis.
 
-    :param checkpoints: name of the checkpoint
+    :param checkpoints: name of the trained model (.h5 or .pickle file)
     :param type: recurrent or feedforward
     :param task: regression or classification
     :param framework: keras or scikit
