@@ -2,7 +2,7 @@
 
 import argparse
 
-from aidkitcli.data_access.api import RESTApi
+from aidkitcli.data_access.upload import upload_data, list_data
 
 
 def main():
@@ -25,12 +25,10 @@ def main():
 
     args = argument_parser.parse_args()
 
-    api = RESTApi()
-
     if args.file is None:
-        return api.list_data()
+        return list_data()
     else:
-        return api.post_data(zip_path=args.file)
+        return upload_data(data_set=args.file)
 
 
 if __name__ == "__main__":
