@@ -3,6 +3,7 @@
 import argparse
 
 from aidkitcli.data_access.api import RESTApi
+from aidkitcli.data_access.upload import upload_model, list_models
 
 
 def main():
@@ -22,12 +23,10 @@ def main():
 
     args = argument_parser.parse_args()
 
-    api = RESTApi()
-
     if args.file is None:
-        return api.list_models()
+        return list_models()
     else:
-        return api.post_model(model_path=args.file)
+        return upload_model(model_path=args.file)
 
 
 if __name__ == "__main__":
